@@ -1,6 +1,6 @@
 #
 # Author:: Patrick Wright (<patrick@chef.io>)
-# Copyright:: Copyright (c) 2015 Chef, Inc.
+# Copyright:: Copyright (c) 2015-2018 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-require "mixlib/install/backend/package_router"
+require_relative "backend/package_router"
 
 module Mixlib
   class Install
