@@ -1,5 +1,5 @@
 #
-# Copyright:: Copyright (c) 2015 Chef, Inc.
+# Copyright:: Copyright (c) 2015-2018 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,8 +15,8 @@
 # limitations under the License.
 #
 
-require "mixlib/install/generator/bourne"
-require "mixlib/install/generator/powershell"
+require_relative "generator/bourne"
+require_relative "generator/powershell"
 
 module Mixlib
   class Install
