@@ -1,5 +1,5 @@
 #
-# Copyright:: Copyright (c) 2015 Chef, Inc.
+# Copyright:: Copyright (c) 2015-2018 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,9 +15,10 @@
 # limitations under the License.
 #
 
-require "erb"
-require "ostruct"
-require "mixlib/install/util"
+require "erb" unless defined?(Erb)
+require "ostruct" unless defined?(OpenStruct)
+require_relative "../util"
+require_relative "../dist"
 
 module Mixlib
   class Install
@@ -44,10 +45,17 @@ module Mixlib
           script_path = File.join(script_base_path, name)
 
           # If there is an erb template we render it, otherwise we just read
-          # and returnt the contents of the script
+          # and return the contents of the script
           if File.exist? "#{script_path}.erb"
             # Default values to use incase they are not set in the context
-            context[:base_url] ||= "https://omnitruck.chef.io"
+            context[:project_name] ||= Mixlib::Install::Dist::PROJECT_NAME.freeze
+            context[:base_url] ||= Mixlib::Install::Dist::OMNITRUCK_ENDPOINT.freeze
+            context[:default_product] ||= Mixlib::Install::Dist::DEFAULT_PRODUCT.freeze
+            context[:bug_url] ||= Mixlib::Install::Dist::BUG_URL.freeze
+            context[:support_url] ||= Mixlib::Install::Dist::SUPPORT_URL.freeze
+            context[:resources_url] ||= Mixlib::Install::Dist::RESOURCES_URL.freeze
+            context[:macos_dir] ||= Mixlib::Install::Dist::MACOS_VOLUME.freeze
+            context[:windows_dir] ||= Mixlib::Install::Dist::WINDOWS_INSTALL_DIR.freeze
             context[:user_agent_string] = Util.user_agent_string(context[:user_agent_headers])
 
             context_object = OpenStruct.new(context).instance_eval { binding }
