@@ -12,9 +12,9 @@
 #
 # Platform and Platform Version detection
 #
-# NOTE: This should now match ohai platform and platform_version matching.
-# do not invented new platform and platform_version schemas, just make this behave
-# like what ohai returns as platform and platform_version for the server.
+# NOTE: This logic should match ohai platform and platform_version matching.
+# do not invent new platform and platform_version schemas, just make this behave
+# like what ohai returns as platform and platform_version for the system.
 #
 # ALSO NOTE: Do not mangle platform or platform_version here.  It is less error
 # prone and more future-proof to do that in the server, and then all omnitruck clients
@@ -25,7 +25,7 @@
 machine=`uname -m`
 os=`uname -s`
 
-if test -f "/etc/lsb-release" && grep -q DISTRIB_ID /etc/lsb-release && ! grep -q wrlinux /etc/lsb-release; then
+if test -f "/etc/lsb-release" && grep DISTRIB_ID /etc/lsb-release >/dev/null && ! grep wrlinux /etc/lsb-release >/dev/null; then
   platform=`grep DISTRIB_ID /etc/lsb-release | cut -d "=" -f 2 | tr '[A-Z]' '[a-z]'`
   platform_version=`grep DISTRIB_RELEASE /etc/lsb-release | cut -d "=" -f 2`
 
@@ -48,7 +48,7 @@ elif test -f "/etc/redhat-release"; then
   platform_version=`sed 's/^.\+ release \([.0-9]\+\).*/\1/' /etc/redhat-release`
 
   if test "$platform" = "xenserver"; then
-    # Current XenServer 6.2 is based on CentOS 5, platform is not reset to "el" server should hanlde response
+    # Current XenServer 6.2 is based on CentOS 5, platform is not reset to "el" server should handle response
     platform="xenserver"
   else
     # FIXME: use "redhat"
@@ -71,20 +71,14 @@ elif test -f "/etc/system-release"; then
     fi
   esac
 
-# Apple OS X
+# Apple macOS
 elif test -f "/usr/bin/sw_vers"; then
   platform="mac_os_x"
   # Matching the tab-space with sed is error-prone
   platform_version=`sw_vers | awk '/^ProductVersion:/ { print $2 }' | cut -d. -f1,2`
-
-  # x86_64 Apple hardware often runs 32-bit kernels (see OHAI-63)
-  x86_64=`sysctl -n hw.optional.x86_64`
-  if test $x86_64 -eq 1; then
-    machine="x86_64"
-  fi
 elif test -f "/etc/release"; then
   machine=`/usr/bin/uname -p`
-  if grep -q SmartOS /etc/release; then
+  if grep SmartOS /etc/release >/dev/null; then
     platform="smartos"
     platform_version=`grep ^Image /etc/product | awk '{ print $3 }'`
   else
@@ -92,11 +86,11 @@ elif test -f "/etc/release"; then
     platform_version=`/usr/bin/uname -r`
   fi
 elif test -f "/etc/SuSE-release"; then
-  if grep -q 'Enterprise' /etc/SuSE-release;
+  if grep 'Enterprise' /etc/SuSE-release >/dev/null;
   then
       platform="sles"
       platform_version=`awk '/^VERSION/ {V = $3}; /^PATCHLEVEL/ {P = $3}; END {print V "." P}' /etc/SuSE-release`
-  else
+  else # opensuse 43 only. 15 ships with /etc/os-release only
       platform="opensuseleap"
       platform_version=`awk '/^VERSION =/ { print $3 }' /etc/SuSE-release`
   fi
@@ -114,7 +108,14 @@ elif test -f "/etc/os-release"; then
   fi
 
   platform=$ID
-  platform_version=$VERSION
+
+  # VERSION_ID is always the preferred variable to use, but not
+  # every distro has it so fallback to VERSION
+  if test "x$VERSION_ID" != "x"; then
+    platform_version=$VERSION_ID
+  else
+    platform_version=$VERSION
+  fi
 fi
 
 if test "x$platform" = "x"; then
@@ -124,7 +125,7 @@ if test "x$platform" = "x"; then
 fi
 
 #
-# NOTE: platform manging in the install.sh is DEPRECATED
+# NOTE: platform mangling in the install.sh is DEPRECATED
 #
 # - install.sh should be true to ohai and should not remap
 #   platform or platform versions.
@@ -163,6 +164,9 @@ esac
 
 # normalize the architecture we detected
 case $machine in
+  "arm64"|"aarch64")
+    machine="aarch64"
+    ;;
   "x86_64"|"amd64"|"x64")
     machine="x86_64"
     ;;
