@@ -5,24 +5,32 @@
 
 if test "x$https_proxy" != "x"; then
   echo "setting https_proxy: $https_proxy"
-  export HTTPS_PROXY=$https_proxy
-  export https_proxy=$https_proxy
+  HTTPS_PROXY=$https_proxy
+  https_proxy=$https_proxy
+  export HTTPS_PROXY
+  export https_proxy
 fi
 
 if test "x$http_proxy" != "x"; then
   echo "setting http_proxy: $http_proxy"
-  export HTTP_PROXY=$http_proxy
-  export http_proxy=$http_proxy
+  HTTP_PROXY=$http_proxy
+  http_proxy=$http_proxy
+  export HTTP_PROXY
+  export http_proxy
 fi
 
 if test "x$ftp_proxy" != "x"; then
   echo "setting ftp_proxy: $ftp_proxy"
-  export FTP_PROXY=$ftp_proxy
-  export ftp_proxy=$ftp_proxy
+  FTP_PROXY=$ftp_proxy
+  ftp_proxy=$ftp_proxy
+  export FTP_PROXY
+  export ftp_proxy
 fi
 
 if test "x$no_proxy" != "x"; then
   echo "setting no_proxy: $no_proxy"
-  export NO_PROXY=$no_proxy
-  export no_proxy=$no_proxy
+  NO_PROXY=$no_proxy
+  no_proxy=$no_proxy
+  export NO_PROXY
+  export no_proxy
 fi
