@@ -1,6 +1,6 @@
 #
 # Author:: Patrick Wright (<patrick@chef.io>)
-# Copyright:: Copyright (c) 2015 Chef, Inc.
+# Copyright:: Copyright (c) 2015-2018 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,8 +16,9 @@
 # limitations under the License.
 #
 
-require "mixlib/install/product"
-require "mixlib/install/util"
+require_relative "product"
+require_relative "product_matrix"
+require_relative "util"
 require "mixlib/versioning"
 
 module Mixlib
@@ -29,6 +30,7 @@ module Mixlib
 
       SUPPORTED_ARCHITECTURES = %w{
         aarch64
+        armv7l
         i386
         powerpc
         ppc64
@@ -231,7 +233,7 @@ Must be one of: #{SUPPORTED_SHELL_TYPES.join(", ")}
       def validate_platform_options
         unless all_or_none?(platform_info.values)
           errors << <<-EOS
-Must provide platform, platform version and architecture when specifying any platform details
+Must provide platform (-p), platform version (-l) and architecture (-a) when specifying any platform details
           EOS
         end
       end
