@@ -1,7 +1,7 @@
 #
 # Author:: Thom May (<thom@chef.io>)
 # Author:: Patrick Wright (<patrick@chef.io>)
-# Copyright:: Copyright (c) 2015 Chef, Inc.
+# Copyright:: Copyright (c) 2015-2018 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,8 +17,9 @@
 # limitations under the License.
 #
 
-require "mixlib/install/util"
-require "mixlib/install/generator/powershell"
+require_relative "util"
+require_relative "generator/powershell"
+require_relative "dist"
 require "cgi"
 
 module Mixlib
@@ -83,9 +84,9 @@ module Mixlib
         @sudo_command = "sudo -E"
 
         @root = if powershell
-                  "$env:systemdrive\\opscode\\chef"
+                  "$env:systemdrive\\#{Mixlib::Install::Dist::WINDOWS_INSTALL_DIR}\\#{Mixlib::Install::Dist::DEFAULT_PRODUCT}"
                 else
-                  "/opt/chef"
+                  "#{Mixlib::Install::Dist::LINUX_INSTALL_DIR}/#{Mixlib::Install::Dist::DEFAULT_PRODUCT}"
                 end
 
         parse_opts(opts)
@@ -226,7 +227,7 @@ module Mixlib
       # Conditionally prefixes a command with a sudo command.
       #
       # @param command [String] command to be prefixed
-      # @return [String] the command, conditionaly prefixed with sudo
+      # @return [String] the command, conditionally prefixed with sudo
       # @api private
       def sudo(script)
         use_sudo ? "#{sudo_command} #{script}" : script
