@@ -1,6 +1,6 @@
 #
 # Author:: Thom May (<thom@chef.io>)
-# Copyright:: Copyright (c) 2015 Chef, Inc.
+# Copyright:: Copyright (c) 2015-2018 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -66,10 +66,13 @@ module Mixlib
             env << Util.shell_env_var("https_proxy", opts[:https_proxy], powershell)
             env << Util.shell_env_var("HTTPS_PROXY", opts[:https_proxy], powershell)
           end
+          unless env.empty?
+            code = env.join("\n").concat("\n").concat(code)
+          end
           if powershell
-            env.join("\n").concat("\n").concat(code)
+            "\n" + code
           else
-            Util.wrap_command(env.join("\n").concat("\n").concat(code))
+            Util.wrap_command(code)
           end
         end
 
@@ -106,7 +109,7 @@ module Mixlib
         # invoked on a remote instance or locally.
         #
         # This method uses the Bourne shell (/bin/sh) to maximize the chance of
-        # cross platform portability on Unixlike systems.
+        # cross platform portability on Unix-like systems.
         #
         # @param [String] the command
         # @return [String] a wrapped command string
@@ -123,10 +126,10 @@ module Mixlib
         # @param name [Array] headers
         # @return [String] generated user-agent string
         def user_agent_string(headers)
-          require "mixlib/install/version"
+          require_relative "version"
           user_agents = %W{mixlib-install/#{Mixlib::Install::VERSION}}
           user_agents << headers
-          # Ensure that if the default user agent is aleady set it doesn't get duplicated
+          # Ensure that if the default user agent is already set it doesn't get duplicated
           user_agents.flatten.compact.uniq.join(" ")
         end
 
@@ -159,6 +162,8 @@ module Mixlib
           case architecture
           when "amd64"
             "x86_64"
+          when "arm64"
+            "aarch64"
           when "i86pc", "i686"
             "i386"
           when "sun4u", "sun4v"
