@@ -90,7 +90,7 @@ context "Mixlib::Install::Backend::PackageRouter all channels", :vcr do
           expect(artifact_info.platform).to eq "ubuntu"
         end
 
-        it "has the right platfom version" do
+        it "has the right platform version" do
           expect(artifact_info.platform_version).to eq "14.04"
         end
 
@@ -111,7 +111,7 @@ context "Mixlib::Install::Backend::PackageRouter all channels", :vcr do
         end
 
         it "has the right product description" do
-          expect(artifact_info.product_description).to eq "Chef Client"
+          expect(artifact_info.product_description).to eq "Chef Infra Client"
         end
 
         it "has the right url" do
@@ -448,36 +448,53 @@ context "Mixlib::Install::Backend::PackageRouter all channels", :vcr do
       artifact_info.find_all { |a| a.platform == "windows" }
     end
 
-    shared_examples_for "windows desktop download urls and expected architectures" do
+    shared_examples_for "windows download urls and architectures" do
       it "returns server download url for associated desktop versions" do
-        expect(windows_artifacts.find { |a| a.platform_version == "10" }.url).to include "2012r2"
+        expected = product_name == "push-jobs-client" ? "2012r2" : "/windows/10/"
+        expect(windows_artifacts.find { |a| a.platform_version == "10" }.url).to include expected
       end
 
       it "maps architecture to correct filename" do
-        expect(windows_artifacts.find { |a| a.platform_version == "10" && a.architecture == "i386" }.url).to include "-x86"
-        expect(windows_artifacts.find { |a| a.platform_version == "10" && a.architecture == "x86_64" }.url).to include expected_64_bit_msi
+        artifact_32 = windows_artifacts.find { |a| a.platform_version == "10" && a.architecture == "i386" }
+        artifact_64 = windows_artifacts.find { |a| a.platform_version == "10" && a.architecture == "x86_64" }
+        expect(artifact_32.url).to include "-x86" if artifact_32 # not all projects have 32-bit packages
+        expect(artifact_64.url).to include expected_64_bit_msi
       end
     end
 
-    context "chef windows artifacts" do
+    context "chef artifacts" do
       let(:product_name) { "chef" }
       let(:expected_64_bit_msi) { "-x64" }
 
-      it_behaves_like "windows desktop download urls and expected architectures"
+      it_behaves_like "windows download urls and architectures"
     end
 
-    context "chefdk windows artifacts" do
+    context "chefdk artifacts" do
       let(:product_name) { "chefdk" }
-      let(:expected_64_bit_msi) { "-x86" }
+      let(:expected_64_bit_msi) { "-x64" }
 
-      it_behaves_like "windows desktop download urls and expected architectures"
+      it_behaves_like "windows download urls and architectures"
     end
 
-    context "push-jobs-client windows artifacts" do
+    context "push-jobs-client artifacts" do
       let(:product_name) { "push-jobs-client" }
-      let(:expected_64_bit_msi) { "-x86" }
+      let(:expected_64_bit_msi) { "-x64" }
 
-      it_behaves_like "windows desktop download urls and expected architectures"
+      it_behaves_like "windows download urls and architectures"
+    end
+
+    context "inspec artifacts" do
+      let(:product_name) { "inspec" }
+      let(:expected_64_bit_msi) { "-x64" }
+
+      it_behaves_like "windows download urls and architectures"
+    end
+
+    context "chef-workstation artifacts" do
+      let(:product_name) { "inspec" }
+      let(:expected_64_bit_msi) { "-x64" }
+
+      it_behaves_like "windows download urls and architectures"
     end
   end
 
